@@ -21,17 +21,12 @@
  */
 
 #include "config.h"
-
-#include <string.h>
-
-#include <gtk/gtk.h>
-
-#include <libempathy/empathy-gsettings.h>
-
 #include "empathy-theme-manager.h"
 
+#include "empathy-gsettings.h"
+
 #define DEBUG_FLAG EMPATHY_DEBUG_OTHER
-#include <libempathy/empathy-debug.h>
+#include "empathy-debug.h"
 
 struct _EmpathyThemeManagerPriv
 {
