@@ -62,8 +62,10 @@ GType empathy_call_window_get_type (void);
     EmpathyCallWindowClass))
 
 EmpathyCallWindow *empathy_call_window_new (EmpathyCallHandler *handler);
-void empathy_call_window_present (EmpathyCallWindow *window,
-  EmpathyCallHandler *handler);
+void empathy_call_window_new_handler (EmpathyCallWindow *window,
+  EmpathyCallHandler *handler,
+  gboolean present,
+  guint32 x11_time);
 void empathy_call_window_start_ringing (EmpathyCallWindow *self,
   TpCallChannel *channel,
   TpChannelDispatchOperation *dispatch_operation,
