@@ -79,13 +79,18 @@ struct _TpawAvatarChooserPrivate
   gboolean changed;
 
   GtkFileChooser *chooser_dialog;
+#ifdef ENABLE_SETTINGS
   GSettings *gsettings_ui;
+#endif
+
+  gint pixel_size;
 };
 
 enum
 {
   PROP_0,
-  PROP_ACCOUNT
+  PROP_ACCOUNT,
+  PROP_PIXEL_SIZE
 };
 
 G_DEFINE_TYPE (TpawAvatarChooser, tpaw_avatar_chooser, GTK_TYPE_BUTTON);
@@ -203,12 +208,24 @@ avatar_chooser_get_property (GObject *object,
       case PROP_ACCOUNT:
         g_value_set_object (value, self->priv->account);
         break;
+      case PROP_PIXEL_SIZE:
+        g_value_set_int (value, self->priv->pixel_size);
+        break;
       default:
         G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
         break;
     }
 }
 
+static void
+avatar_chooser_set_pixel_size (TpawAvatarChooser *self,
+    gint pixel_size)
+{
+  if (pixel_size == -1)
+    pixel_size = AVATAR_SIZE_VIEW;
+  self->priv->pixel_size = pixel_size;
+}
+
 static void
 avatar_chooser_set_property (GObject *object,
     guint param_id,
@@ -223,6 +240,9 @@ avatar_chooser_set_property (GObject *object,
         g_assert (self->priv->account == NULL); /* construct-only */
         self->priv->account = g_value_dup_object (value);
         break;
+      case PROP_PIXEL_SIZE:
+        avatar_chooser_set_pixel_size (self, g_value_get_int (value));
+        break;
       default:
         G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
         break;
@@ -237,7 +257,9 @@ avatar_chooser_dispose (GObject *object)
   tp_clear_object (&self->priv->account);
   tp_clear_pointer (&self->priv->avatar, g_array_unref);
   tp_clear_pointer (&self->priv->mime_type, g_free);
+#ifdef ENABLE_SETTINGS
   tp_clear_object (&self->priv->gsettings_ui);
+#endif
 
   G_OBJECT_CLASS (tpaw_avatar_chooser_parent_class)->dispose (object);
 }
@@ -271,6 +293,25 @@ tpaw_avatar_chooser_class_init (TpawAvatarChooserClass *klass)
            PROP_ACCOUNT,
            param_spec);
 
+  /**
+   * TpawAvatarChooser:pixel-size:
+   *
+   * The size at which the avatar is shown in pixels. If set to -1
+   * then a default value of 64 is used.
+   */
+  param_spec = g_param_spec_int ("pixel-size",
+            "Pixel size",
+            "Pixel size at which the avatar is shown",
+            -1,
+            G_MAXINT,
+            AVATAR_SIZE_VIEW,
+            G_PARAM_READWRITE |
+            G_PARAM_CONSTRUCT_ONLY |
+            G_PARAM_STATIC_STRINGS);
+  g_object_class_install_property (object_class,
+           PROP_PIXEL_SIZE,
+           param_spec);
+
   g_type_class_add_private (object_class, sizeof (TpawAvatarChooserPrivate));
 }
 
@@ -725,7 +766,7 @@ avatar_chooser_set_image (TpawAvatarChooser *self,
   self->priv->changed = TRUE;
 
   pixbuf_view = tpaw_pixbuf_scale_down_if_necessary (pixbuf,
-      AVATAR_SIZE_VIEW);
+      self->priv->pixel_size);
   image = gtk_image_new_from_pixbuf (pixbuf_view);
 
   gtk_button_set_image (GTK_BUTTON (self), image);
@@ -967,12 +1008,15 @@ avatar_chooser_response_cb (GtkWidget *widget,
   if (response == TPAW_AVATAR_CHOOSER_RESPONSE_FILE)
     {
       gchar *filename;
+#ifdef ENABLE_SETTINGS
       gchar *path;
+#endif
 
       filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (widget));
       avatar_chooser_set_image_from_file (self, filename);
       g_free (filename);
 
+#ifdef ENABLE_SETTINGS
       path = gtk_file_chooser_get_current_folder (GTK_FILE_CHOOSER (widget));
       if (path != NULL)
         {
@@ -982,6 +1026,7 @@ avatar_chooser_response_cb (GtkWidget *widget,
 
           g_free (path);
         }
+#endif
     }
   else if (response == TPAW_AVATAR_CHOOSER_RESPONSE_NO_IMAGE)
     {
@@ -1014,17 +1059,12 @@ avatar_chooser_clicked_cb (GtkWidget *button,
   TpawCameraMonitor *monitor;
 #endif
 
-  if (self->priv->chooser_dialog != NULL)
-    {
-      gtk_window_present (GTK_WINDOW (self->priv->chooser_dialog));
-      return;
-    }
-
   self->priv->chooser_dialog = GTK_FILE_CHOOSER (
       gtk_file_chooser_dialog_new (_("Select Your Avatar Image"),
         tpaw_get_toplevel_window (GTK_WIDGET (self)),
         GTK_FILE_CHOOSER_ACTION_OPEN,
         NULL, NULL));
+  gtk_window_set_modal (GTK_WINDOW (self->priv->chooser_dialog), TRUE);
 
 #ifdef HAVE_CHEESE
   picture_button = gtk_dialog_add_button (
@@ -1051,8 +1091,10 @@ avatar_chooser_clicked_cb (GtkWidget *button,
   gtk_window_set_destroy_with_parent (GTK_WINDOW (chooser_dialog), TRUE);
 
   /* Get special dirs */
+#ifdef ENABLE_SETTINGS
   saved_dir = g_settings_get_string (self->priv->gsettings_ui,
              TPAW_PREFS_UI_AVATAR_DIRECTORY);
+#endif
 
   if (saved_dir != NULL &&
       !g_file_test (saved_dir, G_FILE_TEST_IS_DIR))
@@ -1132,7 +1174,9 @@ tpaw_avatar_chooser_init (TpawAvatarChooser *self)
       G_N_ELEMENTS (drop_types),
       GDK_ACTION_COPY);
 
+#ifdef ENABLE_SETTINGS
   self->priv->gsettings_ui = g_settings_new (TPAW_PREFS_UI_SCHEMA);
+#endif
 
   g_signal_connect (self, "drag-motion",
       G_CALLBACK (avatar_chooser_drag_motion_cb),
@@ -1153,18 +1197,21 @@ tpaw_avatar_chooser_init (TpawAvatarChooser *self)
 /**
  * tpaw_avatar_chooser_new:
  * @account: a #TpAccount
+ * @pixel_size: the size at which the avatar is shown in pixels
  *
- * Creates a new #TpawAvatarChooser.
+ * Creates a new #TpawAvatarChooser. If @pixel_size is -1 then a
+ * default value of 64 is used.
  *
  * Return value: a new #TpawAvatarChooser
  */
 GtkWidget *
-tpaw_avatar_chooser_new (TpAccount *account)
+tpaw_avatar_chooser_new (TpAccount *account, gint pixel_size)
 {
   g_return_val_if_fail (TP_IS_ACCOUNT (account), NULL);
 
   return g_object_new (TPAW_TYPE_AVATAR_CHOOSER,
       "account", account,
+      "pixel-size", pixel_size,
       NULL);
 }
 
